@@ -7,6 +7,7 @@
 ** (see the file 'base_main.php' for license details)
 **
 ** Project Leads: Kevin Johnson <kjohnson@secureideas.net>
+**                Sean Muller <samwise_diver@users.sourceforge.net>
 ** Built upon work by Roman Danyliw <rdd@cert.org>, <roman@danyliw.com>
 **
 ** Purpose: Logout -- axe the cookie, redir to index.php 
@@ -18,6 +19,7 @@
 ********************************************************************************
 */
 include("base_conf.php");
+include_once("$BASE_path/base_common.php");
 setcookie('BASERole', "", time()-600000);
-header("Location: ". $BASE_urlpath . "/index.php");
+base_header("Location: ". $BASE_urlpath . "/index.php");
 ?>
