@@ -7,6 +7,7 @@
 ** (see the file 'base_main.php' for license details)
 **
 ** Project Leads: Kevin Johnson <kjohnson@secureideas.net>
+**                Sean Muller <samwise_diver@users.sourceforge.net>
 ** Built upon work by Roman Danyliw <rdd@cert.org>, <roman@danyliw.com>
 **
 ** Purpose: Binary download of payload and pcap format packet download
@@ -34,7 +35,8 @@ include ("$BASE_path/includes/base_include.inc.php");
   $BUser = new BaseUser();
   if (($BUser->hasRole($roleneeded) == 0) && ($Use_Auth_System == 1))
   {
-    header("Location: ". $BASE_urlpath . "/index.php");
+    base_header("Location: ". $BASE_urlpath . "/index.php");
+    exit();
   }
 
 $cid = ImportHTTPVar("cid", VAR_DIGIT);
