@@ -7,6 +7,7 @@
 ** (see the file 'base_main.php' for license details)
 **
 ** Project Lead: Kevin Johnson <kjohnson@secureideas.net>
+**                Sean Muller <samwise_diver@users.sourceforge.net>
 ** Built upon work by Roman Danyliw <rdd@cert.org>, <roman@danyliw.com>
 **
 ** Purpose: manages the necessary state information for
@@ -344,7 +345,8 @@ class QueryState
      echo "<!-- Saving Query State -->\n";
      ExportHTTPVar("caller", $this->current_canned_query);
      ExportHTTPVar("num_result_rows", $this->num_result_rows);
-     ExportHTTPVar("sort_order", $this->current_sort_order);
+     // The below line is commented to fix bug #1761605 please verify this doesnt break anything else -- Kevin Johnson
+     //ExportHTTPVar("sort_order", $this->current_sort_order);
      ExportHTTPVar("current_view", $this->current_view);
   }
 
