@@ -7,6 +7,7 @@
 ** (see the file 'base_main.php' for license details)
 **
 ** Project Leads: Kevin Johnson <kjohnson@secureideas.net>
+**                Sean Muller <samwise_diver@users.sourceforge.net>
 ** Built upon work by Roman Danyliw <rdd@cert.org>, <roman@danyliw.com>
 **
 ** Purpose: English language file
@@ -769,7 +770,7 @@ DEFINE('_QCERRDATETIME','La date ou l\'heure');
 DEFINE('_QCERRPAYLOAD','Le contenu (payload)');
 // A payload value of
 DEFINE('_QCERRIP','L\'adresse IP');
-// A IP address of
+// An IP address of
 DEFINE('_QCERRIPTYPE','Une adresse IP de type');
 // An IP address of type
 DEFINE('_QCERRSPECFIELD','tait saisi pour un champ de protocole, mais le champ prcis n\'est pas spcifi.');
@@ -876,8 +877,8 @@ DEFINE('_SCPORT','Port');
 //base_stat_ipaddr.php
 DEFINE('_PSEVENTERR','ERREUR D\'EVENEMENT PORTSCAN');
 // PORTSCAN EVENT ERROR: 
-DEFINE('_PSEVENTERRNOFILE','Aucun fichier prcis dans la variable \$portscan_file.');
-// No file was specified in the \$portscan_file variable.
+DEFINE('_PSEVENTERRNOFILE','Aucun fichier prcis dans la variable $portscan_file.');
+// No file was specified in the $portscan_file variable.
 DEFINE('_PSEVENTERROPENFILE','Impossible d\ouvrir le fichier des vnements Portscan.');
 // Unable to open Portscan event file
 DEFINE('_PSDATETIME','Date/Heure');
