@@ -7,6 +7,7 @@
 ** (see the file 'base_main.php' for license details)
 **
 ** Project Leads: Kevin Johnson <kjohnson@secureideas.net>
+**                Sean Muller <samwise_diver@users.sourceforge.net>
 ** Built upon work by Roman Danyliw <rdd@cert.org>, <roman@danyliw.com>
 **
 ** Purpose: English language file
@@ -609,7 +610,7 @@ DEFINE('_SCPORT','Porta');
 
 //base_stat_ipaddr.php
 DEFINE('_PSEVENTERR','ERRORE EVENTO PORTSCA: ');
-DEFINE('_PSEVENTERRNOFILE','Nessun file specificato nella variabile \$portscan_file.');
+DEFINE('_PSEVENTERRNOFILE','Nessun file specificato nella variabile $portscan_file.');
 DEFINE('_PSEVENTERROPENFILE','Impossibile aprire il file degli eventi Portscan');
 DEFINE('_PSDATETIME','Data/Ora');
 DEFINE('_PSSRCIP','IP Sorgente');
