@@ -7,6 +7,7 @@
 ** (see the file 'base_main.php' for license details)
 **
 ** Project Leads: Kevin Johnson <kjohnson@secureideas.net>
+**                Sean Muller <samwise_diver@users.sourceforge.net>
 ** Built upon work by Roman Danyliw <rdd@cert.org>, <roman@danyliw.com>
 **
 ** Purpose: This file is the third step in the setup program
@@ -42,6 +43,7 @@ if (@$_GET['action'] == "check")
    if ($error != 1)
    {
       header("Location: setup4.php");
+      exit();
    }
 
 }
@@ -72,7 +74,7 @@ if (@$_GET['action'] == "check")
 <center><table width="50%" border=1 class ="query">
 <tr><td colspan=2 align="center" class="setupTitle">Step 3 of 5</td><tr>
 <tr><td colspan=2 align="center">&nbsp;</td></tr>
-<tr><td colspan=2 align="center"><input type="checkbox" name="useuserauth" <?php if ($_SESSION['useuserauth']) echo "checked";?>>Use Authentication System [<a href="#" onClick="javascript:window.open('../help/base_setup_help.php#useauth','helpscreen','width=300,height=300');">?</a>]</td></tr>
+<tr><td colspan=2 align="center"><input type="checkbox" name="useuserauth" <?php if ($_SESSION['useuserauth']) echo "checked";?>>Use Authentication System [<a href="../help/base_setup_help.php#useauth" onClick="javascript:window.open('../help/base_setup_help.php#useauth','helpscreen','width=300,height=300');">?</a>]</td></tr>
 <tr><td class="setupKey">Admin User Name:</td><td class="setupValue"><input type="text" name="usrlogin" value="<?php echo $_SESSION['usrlogin'];?>"></td></tr>
 <tr><td class="setupKey">Password:</td><td class="setupValue"><input type="password" name="usrpasswd" value="<?php echo $_SESSION['usrpasswd'];?>"></td></tr>
 <tr><td class="setupKey">Full Name:</td><td class="setupValue"><input type="text" name="usrname" value="<?php echo $_SESSION['usrname'];?>"></td></tr>
