@@ -7,6 +7,7 @@
 ** (see the file 'base_main.php' for license details)
 **
 ** Project Leads: Kevin Johnson <kjohnson@secureideas.net>
+**                Sean Muller <samwise_diver@users.sourceforge.net>
 ** Built upon work by Roman Danyliw <rdd@cert.org>, <roman@danyliw.com>
 **
 ** Purpose: Setup step 4, create the database stuff
@@ -58,25 +59,66 @@ if (file_exists('../base_conf.php'))
 <FORM METHOD="POST" ACTION="setup4.php">
 
 <?php
+  GLOBAL $debug_mode;
   $submit = ImportHTTPVar("submit", VAR_ALPHA | VAR_SPACE);
 
-   // Grab the variables that have been put into Session
-   $alert_dbname = $_SESSION['dbname'];
-   $alert_host =  $_SESSION['dbhost'];
-   $alert_port =  $_SESSION['dbport'];
-   $alert_user = $_SESSION['dbusername'];
-   $alert_password = $_SESSION['dbpasswd'];
-   $DBlib_path = $_SESSION['adodbpath'];
-   $DBtype = $_SESSION['dbtype'];
+  // Grab the variables that have been put into Session
+  $alert_dbname = $_SESSION['dbname'];
+  $alert_host =  $_SESSION['dbhost'];
+  $alert_port =  $_SESSION['dbport'];
+  $alert_user = $_SESSION['dbusername'];
+  $alert_password = $_SESSION['dbpasswd'];
+  $DBlib_path = $_SESSION['adodbpath'];
+  $DBtype = $_SESSION['dbtype'];
+
+  /* Archive database */ 
+  if ( $submit == "Create BASE AG" ) 
+  {
+    if ($_SESSION['usearchive'] == 1)
+    {
+      if ($_SESSION['arcdbexists'])
+      {
+        $archive_dbname = $_SESSION['arcdbname'];
+        $archive_host =  $_SESSION['arcdbhost'];
+        $archive_port =  $_SESSION['arcdbport'];
+        $archive_user = $_SESSION['arcdbusername'];
+        $archive_password = $_SESSION['arcdbpasswd'];
+        $archive = NewBASEDBConnection($DBlib_path, $DBtype);
+        $archive->baseDBConnect(1, $archive_dbname, $archive_host, $archive_port, $archive_user, $archive_password, 1);
+        $archive_result = CreateBASEAG($archive);
+        if ($archive_result != 1)					 
+        {
+          error_message("ERROR: Trying to add BASE specific tables to the archive database has failed. <BR>\n");
+          if ( $archive->baseErrorMessage() != "" )
+          {
+            ErrorMessage($archive->baseErrorMessage());
+          }
+        } 
+        else if ($debug_mode > 0)
+        {
+          echo "<BR>";
+          ErrorMessage("BASE tables added to $archive->DB_name.");
+          echo "<BR>\n";
+        }
+			}
+    }
+  }
 
   /* Connect to the Alert database */
   $db = NewBASEDBConnection($DBlib_path, $DBtype);
   $db->baseDBConnect(1,$alert_dbname, $alert_host, $alert_port, $alert_user, $alert_password, 1);
 
-  if ( $submit == "Create BASE AG" ) {
-     $result = CreateBASEAG($db);
-     echo '<HR><P>';
-  }
+  if ( $submit == "Create BASE AG" ) {		
+    $result = CreateBASEAG($db);
+    if (($debug_mode > 0) && ($result == 1))
+    {
+      echo "<BR>";
+      ErrorMessage("BASE tables added to $db->DB_name.");
+      echo "<BR>\n";
+    }
+	}
+  
+  echo '<HR><P>'; 
 
   echo '
   <TABLE WIDTH="100%">
@@ -86,7 +128,25 @@ if (file_exists('../base_conf.php'))
          <TD CLASS="plfieldhdr">Status</TD>
      </TR>
      <TR><TD VALIGN=TOP><B>BASE tables</B></TD>
-         <TD VALIGN=TOP>Adds tables to extend the Snort DB to support the BASE functionality</TD>
+         <TD VALIGN=TOP>Adds tables to extend the Snort DB to support the BASE functionality<BR>
+         <UL>';
+
+  if ($alert_dbname != "")
+  {
+    echo '<LI>' . $alert_dbname . '<BR>';
+  }
+
+  if ($_SESSION['usearchive'] == 1)
+  {
+    if ($_SESSION['arcdbname'] != "")
+    {
+      echo '<LI>' . $_SESSION['arcdbname'] . '<BR>';
+    }
+  }
+
+  echo ' 
+         </UL>
+         </TD>
          <TD VALIGN=TOP>';
 
   if ($result == 1) {
@@ -137,7 +197,7 @@ if (file_exists('../base_conf.php'))
            <center>Now continue to <a href="setup5.php">step 5</a>...</center>'; 
 
   echo "\n</FORM>\n";
- 
+// vim: tabstop=2:shiftwidth=2:expandtab 
 ?>
 </BODY>
 </HTML>
